<?php

namespace App\Http\Controllers\V1\Bhua;

use App\Services\Api\BhuaProductsService;
use Illuminate\Http\Request;
use Jiannei\Response\Laravel\Support\Facades\Response;
use App\Http\Controllers\V1\Controller;
use App\Support\Traits\Helpers;

use OpenApi\Annotations\Post;
use OpenApi\Annotations\RequestBody;
use OpenApi\Annotations\MediaType;
use OpenApi\Annotations\Schema;
use OpenApi\Annotations\Property;
use OpenApi\Annotations\Response as AnnotationResponse;
use OpenApi\Annotations as OA;

class ProductsController extends Controller
{
    use Helpers;

    public function __construct(BhuaProductsService $bhuaProductService)
    {
       $this->bhuaProdcutService = $bhuaProductService;
    }

    /**
     *
     * @Post(
     *     path="/openapi/bhua/products/getAllBrands",
     *     tags={"百化 - 产品相关接口"},
     *     summary="获取品牌列表",
     *     description="获取品牌列表",
     *     @RequestBody(
     *         @MediaType(
     *             mediaType="application/json",
     *             @Schema(
     *                 required={"pageSize", "pageNo"},
     *                 @Property(property="pageSize", @Schema(type="integer"),description="返回数据集数量"),
     *                 @Property(property="pageNo", @Schema(type="integer"),description="当前页数"),
     *                 example={"pageSize" : 100, "pageNo" : 1}
     *             ),
     *         @OA\Examples(example="pageSize", value="100",summary="每页的数据量"),
     *         @OA\Examples(example="pageNo", value="1",summary="当前页数"),
     *         )
     *     ),
     *     @OA\Parameter(
     *         description="用户获取的token值",
     *         in="header",
     *         name="authorization",
     *         required=true,
     *         @OA\Schema(type="string"),
     *         @OA\Examples(example="authorization", value="bearerNWJiNDhkNzlmNjg0N2FlMmZiYjliZWM3NGVkNzIyMjNleUpsZUhCcGNtVWlPakUyTmpRMk1EazJORGNzSW1oaGMyZ2lPaUl5ZEhsc1JIQlhkWFpNUVdaWGJVRllJbjA9",summary=""),
     *     ),
     *     @AnnotationResponse(
     *         response="200",
     *         description="正常操作响应",
     *         @MediaType(
     *             mediaType="application/json",
     *             @Schema(
     *                 allOf={
     *                     @Schema(ref="#/components/schemas/ApiResponse"),
     *                     @Schema(
     *                         type="object",
     *                         @Property(property="data", ref="#/components/schemas/BrandsList")
     *                     )
     *                 }
     *             )
     *         )
     *     ),
     *     security={
     *         {"bearer_token":{}}
     *     }
     * )
     */
    public function getAllBrands(Request $request)
    {
        $customerCode = $request->get('customer_code');
        if(!$customerCode){
            return Response::ok('客户编号不存在!');
        }

        $requestParams = $this->formatKeysfromArray($request->all(),'toUnderScore');
        $requestParams = array_merge($requestParams,['customer_code' => $customerCode]);

        try{
            $brandsList = $this->bhuaProdcutService->getAllBrands($requestParams);
            if($brandsList){
                $brandsList = $this->formatKeysfromArray($brandsList,'toCamelCase');
            }
            return Response::success($brandsList,'操作成功');
        }catch(\Throwable $exception){
            return $this->returnErrorExecptionResponse($exception,'获取品牌列表失败');
        }
    }

}
